@@ -5,5 +5,6 @@ from .actor import Audio
 from .dummy import DummyAudio
 from .listener import AudioListener
 from .constants import PlaybackState
-from .utils import (calculate_duration, create_buffer, millisecond_to_clocktime,
-                    supported_uri_schemes)
+from .utils import (
+    calculate_duration, create_buffer, millisecond_to_clocktime,
+    supported_uri_schemes)
